============
MEASUREMENTS
============

What is this?
--------------

This is a collection of Python modules containing functions to handel measurements.


Installation
------------

This package can be installed using pip (recommended way):

    ``pip3 install measurements``

or by downloading and running:

    ``python3 setup.py install``


Web sites
---------

The source code of this package is hosted on:

    https://github.com/jor-/measurements

A Python wheel is available on:
    
    https://pypi.python.org/pypi/measurements


Author
------

Joscha Reimer

    jor@informatik.uni-kiel.de


Copyright
---------

Copyright (C) 2011-2016  Joscha Reimer jor@informatik.uni-kiel.de

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
